==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_SashLayoutWindow.h <==
//----------------------------------------------------------------------------
// wxSashLayoutWindow
// extracted from sashlayw.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SASHLAYOUTWINDOW_H__
#define __CLASS_WX_SASHLAYOUTWINDOW_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSashLayoutWindow
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SashLayoutWindow);

//----------------------------------------------------------------------------
// Object declaration for wxSashLayoutWindow
//----------------------------------------------------------------------------
class Object_wx_SashLayoutWindow : public Object_wx_SashWindow {
public:
	Gura_DeclareObjectAccessor(wx_SashLayoutWindow)
public:
	inline Object_wx_SashLayoutWindow(wxSashLayoutWindow *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_SashWindow(Gura_UserClass(wx_SashLayoutWindow), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SashLayoutWindow(Class *pClass, wxSashLayoutWindow *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_SashWindow(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SashLayoutWindow();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSashLayoutWindow *GetEntity() {
		return dynamic_cast<wxSashLayoutWindow *>(_pEntity);
	}
	inline wxSashLayoutWindow *ReleaseEntity() {
		wxSashLayoutWindow *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxSashLayoutWindow");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_SashLayoutWindow.h <==
//----------------------------------------------------------------------------
// wxSashLayoutWindow
// extracted from sashlayw.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SASHLAYOUTWINDOW_H__
#define __CLASS_WX_SASHLAYOUTWINDOW_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSashLayoutWindow
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SashLayoutWindow);

//----------------------------------------------------------------------------
// Object declaration for wxSashLayoutWindow
//----------------------------------------------------------------------------
class Object_wx_SashLayoutWindow : public Object_wx_SashWindow {
public:
	Gura_DeclareObjectAccessor(wx_SashLayoutWindow)
public:
	inline Object_wx_SashLayoutWindow(wxSashLayoutWindow *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_SashWindow(Gura_UserClass(wx_SashLayoutWindow), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SashLayoutWindow(Class *pClass, wxSashLayoutWindow *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_SashWindow(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SashLayoutWindow();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSashLayoutWindow *GetEntity() {
		return dynamic_cast<wxSashLayoutWindow *>(_pEntity);
	}
	inline wxSashLayoutWindow *ReleaseEntity() {
		wxSashLayoutWindow *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxSashLayoutWindow");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
